Learn R Programming

iSTAY (version 1.0.0)

Data_Jena_462_populations: Biomass time series data of 462 populations in the Jena experiment

Description

In the Jena experiment, the biomass of each species sown in a plot was recorded annually from 2003 to 2024, except in 2004. This dataset includes the biomass time series of all 462 populations across 76 plots.

Usage

data(Data_Jena_462_populations)

Arguments

Format

Data_Jena_462_populations is a population-by-time (462 × 21) data frame with population identifiers as rows and time points as columns.