The biomass data for all species sown within each plot are used to form 76 metapopulations. Because the number of species sown per plot ranges from 1 to 16, the number of populations within the 76 plots also ranges from 1 to 16. Each metapopulation dataset therefore includes all population-level records for its constituent species.
data(Data_Jena_76_metapopulations)Data_Jena_76_metapopulations contains 76 lists; each list is a data frame with population identifiers as rows and time points as columns.